/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.raster;

import java.awt.Color;

import java.io.IOException;
import java.io.OutputStream;

/**
 * Little helper class to write a Raster into an output stream
 * as a Netpbm PPM file.
 * @author <a href="mailto:sascha.teichmann@intevation.de">Sascha L. Teichmann</a>
 */
public class RasterToPPM
{
    private RasterToPPM() {
    }

    /**
     * Writes a Raster to a given stream as PPM.
     * @param raster The raster to be written.
     * @param palette The palette used to figure out the rgb values.
     * @param out  The stream to write into.
     * @throws IOException Thrown if some error occurred during writing
     * data to the output stream.
     */
    public static void writeToPPM(
        Raster       raster,
        Palette      palette,
        OutputStream out
    )
    throws IOException
    {
        int W = raster.getWidth();
        int H = raster.getHeight();
        out.write(("P6\n" + W + " " + H + "\n255\n").getBytes("US-ASCII"));
        double [] values = raster.getValues();
        int pos = 0;
        byte [] data = new byte[W*3];
        int black = Color.BLACK.getRGB();
        for (int i = 0; i < H; ++i) {
            for (int j = 0; j < data.length; ++pos) {
                Palette.Entry entry = palette.getEntry(values[pos]);
                int rgb = entry == null
                    ? black
                    : entry.getColor().getRGB();
                data[j++] = (byte)((rgb >> 16) & 0xff);
                data[j++] = (byte)((rgb >>  8) & 0xff);
                data[j++] = (byte)( rgb        & 0xff);
            }
            out.write(data);
        }
        out.flush();
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
