/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.state;

/**
 * This class is used to save the relation between two attributes. Mainly used
 * to save the relation between a measurement and the parameter it belongs to.
 *
 * @see MeasurementState
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ExtendedInputData extends DefaultInputData {

    /**
     * The separater used to separate measurement ids and parameter ids.
     */
    public static final String SEPARATOR = ";";

    /**
     * The parameter this object belongs to.
     */
    protected String parameterid;

    /**
     * Constructcor.
     *
     * @param name
     * @param value
     * @param object
     * @param parameterid
     */
    public ExtendedInputData(
        String name,
        String value,
        Object object,
        String parameterid)
    {
        super(name, value, object);
        this.parameterid = parameterid;
    }

    /**
     * Return the parameter ids this object belongs to.
     *
     * @return the parameter id.
     */
    public String getParameterID() {
        return parameterid;
    }

    /**
     * Set the parameter ids.
     *
     * @param parameterid Parameter ids.
     */
    public void setParameter(String parameterid) {
        this.parameterid = parameterid;
    }

    /**
     * Return all parameter ids as array.
     *
     * @return Array of parameter ids.
     */
    public String[] splitParameter() {
        if (parameterid != null)
            return parameterid.split(SEPARATOR);

        return null;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
